@@ -57,8 +57,8 @@ def minkowski(XA, XB, **kwargs):
     if w is None:
         w = np.ones_like(XA[0])
 
-    Dp -= np.dot(np.isnan(XA), (w * (np.abs(XB0) ** p)).T)
-    Dp -= np.dot(w * (np.abs(XA0) ** p), np.isnan(XB).T)
+    Dp -= np.matmul(np.isnan(XA), (w * (np.abs(XB0) ** p)).T)
+    Dp -= np.matmul(w * (np.abs(XA0) ** p), np.isnan(XB).T)
 
     # Hack: set very small values to zero to prevent inflation by ** (1/p) for larger values of p
     Dp[Dp / np.average(Dp) < 1e-10] = 0
@@ -78,7 +78,7 @@ def _correct_norms(XA, XB, w=None):
     else:
         w = np.array([w])
     return np.sqrt(
-        np.dot(np.square(np.nan_to_num(XA)), w.T * ~np.isnan(XB).T)
+        np.matmul(np.square(np.nan_to_num(XA)), w.T * ~np.isnan(XB).T)
     ) * np.sqrt(np.dot(w * ~np.isnan(XA), np.square(np.nan_to_num(XB).T)))
 
 
@@ -88,7 +88,7 @@ def _uncorrected_norms(XA, XB, w=None):
     if w is None:
         w = np.ones(shape=(1, XA.shape[1]))
     return np.sqrt(
-        np.dot(np.square(np.nan_to_num(XA)), (w * np.ones_like(XB)).T)
+        np.matmul(np.square(np.nan_to_num(XA)), (w * np.ones_like(XB)).T)
     ) * np.sqrt(np.dot(w * np.ones_like(XA), np.square(np.nan_to_num(XB)).T))
 
 
